PyXMake Developer Guide: PyXMake.VTL.stm_make.pyx_bundle Class Reference

| PyXMake Developer Guide 1.0 PyXMake

Loading...
Searching...
No Matches
Public Member Functions | Public Attributes | Static Public Attributes | Protected Member Functions | Static Protected Attributes | List of all members
PyXMake.VTL.stm_make.pyx_bundle Class Reference
Inheritance diagram for PyXMake.VTL.stm_make.pyx_bundle:

## Public Member Functions
| initialize_options (self)
| finalize_options (self)
Public Member Functions inherited from PyXMake.VTL.stm_make._BaseCommandRunner
| run (self)

## Public Attributes
int | verbose = 0
str | source_path = ''
str | output_file_path = ''
| scratch_path = os.getcwd()
str | install_path = "$Desktop"
Public Attributes inherited from PyXMake.VTL.stm_make._BaseCommandRunner
| verbose

## Static Public Attributes
str | description = "Compile a stand-alone installer using NSIS."
list | user_options

## Protected Member Functions
| _run_command (self, command)
Protected Member Functions inherited from PyXMake.VTL.stm_make._BaseCommandRunner
| _create_command (self)
| _perform_post_actions (self)

## Static Protected Attributes
str | _BUNDLE_NAME = ''
str | _INPUT_FILES = ""

## Additional Inherited Members
Static Protected Member Functions inherited from PyXMake.VTL.stm_make._BaseCommandRunner
| _create_build_dir ()

## Detailed Description

    Base class for encapsulating command line arguments and build process.

Definition at line 194 of file stm_make.py.

## Member Function Documentation

## ◆ _run_command()

PyXMake.VTL.stm_make.pyx_bundle._run_command | ( |  | self,
|  |  | command )
| protected

    Execute build command

Reimplemented from PyXMake.VTL.stm_make._BaseCommandRunner.

Definition at line 230 of file stm_make.py.

## ◆ finalize_options()

PyXMake.VTL.stm_make.pyx_bundle.finalize_options | ( |  | self | ) |

    Post-process options.

Definition at line 222 of file stm_make.py.

## ◆ initialize_options()

PyXMake.VTL.stm_make.pyx_bundle.initialize_options | ( |  | self | ) |

    Set default values for options.

Definition at line 211 of file stm_make.py.

## Member Data Documentation

## ◆ _BUNDLE_NAME

PyXMake.VTL.stm_make.pyx_bundle._BUNDLE_NAME = ''
| staticprotected

Definition at line 198 of file stm_make.py.

## ◆ _INPUT_FILES

str PyXMake.VTL.stm_make.pyx_bundle._INPUT_FILES = ""
| staticprotected

Definition at line 199 of file stm_make.py.

## ◆ description

str PyXMake.VTL.stm_make.pyx_bundle.description = "Compile a stand-alone installer using NSIS."
| static

Definition at line 201 of file stm_make.py.

## ◆ install_path

str PyXMake.VTL.stm_make.pyx_bundle.install_path = "$Desktop"

Definition at line 220 of file stm_make.py.

## ◆ output_file_path

str PyXMake.VTL.stm_make.pyx_bundle.output_file_path = ''

Definition at line 218 of file stm_make.py.

## ◆ scratch_path

PyXMake.VTL.stm_make.pyx_bundle.scratch_path = os.getcwd()

Definition at line 219 of file stm_make.py.

## ◆ source_path

PyXMake.VTL.stm_make.pyx_bundle.source_path = ''

Definition at line 217 of file stm_make.py.

## ◆ user_options

list PyXMake.VTL.stm_make.pyx_bundle.user_options
| static

Initial value:
= [
# The format is (long option, short option, description).
('source-path=', None, 'path to the folder holding source files'),
('verbose=', None, 'controls the logging level (0 - Nothing, 2- Everything) Default: 0 - Nothing'),
('scratch-path=', None, 'path to scratch folder where all temporary data is located during the build event'),
('output-file-path=', None, 'path to the output directory'),
('install-path=', None, 'path to the default installation directory'),
]

Definition at line 202 of file stm_make.py.

## ◆ verbose

int PyXMake.VTL.stm_make.pyx_bundle.verbose = 0

Definition at line 216 of file stm_make.py.

The documentation for this class was generated from the following file:

- src/PyXMake/VTL/stm_make.py